## Script (Python) "isMegamanicEditable"
##bind container=container
##bind context=context
##bind namespace=
##bind script=script
##parameters=object=None
##

# Another hack needed because of portal_interfaces..

return False
